%transformer
% Model of a double C-core transformer. The primary coil has a fixed
% number of turns, but the number of secondary windings can be varied.

function transformer

%Secondary turns
Ns = linspace(5,30,1000);

%Number of primary turns
Np = 120;

%Input voltage (RMC AC) to primary coil
Vp_rms = 2.25;

%Relative permeability of iron C-cores
mu = 1000;

%Resistance of primary coil /ohms
r = 5;

%Resistance of seondary coil /ohms
R = 1;

%Mutual inductance coupling constant
k = 0.9;

%AC frequency /Hz
f = 50;

%Primary coil length /m
lp = 1.5/100;

%Secondary coil length /m
ls = 2.0/100;

%C-core cross sectional area /m^2
A = 2.0e-2 * 1.5e-2;

%Permeability of free space
mu0 = 4*pi*1e-7;

%Fontsize
fsize = 16;

%%

%Determine primary voltage amplitude
V0 = Vp_rms*sqrt(2);

%Calculate coil inductances /H
Lp = mu*mu0*(Np^2)*A/lp;
Ls = mu*mu0*(Ns.^2)*A/ls;

%Calculate mutual inductance M
M = k*sqrt( Lp*Ls );

%Calculate A and B coefficients (related to the currents in the primary and
%secondary coils)
w = 2*pi*f;
A = ( 1 + Lp*i*w/r + ( M.^2 )*( w^2 )./( r*( R + Ls*i*w ) ) ).^(-1);
B = i*M*w*R.*A./( r*(R + Ls*i*w ) );

%Calculate (complex) primary and secondary current multipliers of
%exp(i*w*t)
Ip = (V0/r)*A;
Is = (V0/R)*B;

%Secondary voltage /volts
Vs = Is*R;
Vs_rms = abs(Vs)/sqrt(2);
Is_rms = abs(Is)/sqrt(2);

%Powers dissipated in loads r and R /W
Pp = 0.5*real( Ip*r.*conj(Ip) );
Ps = 0.5*real( Is*R.*conj(Is) );

%Power dissipated in primary circuit assuming no secondary coil connection
Pp_no_s = (Vp_rms^2)/r;

%Determine predictions using simple Transformer equation model
Vs_rms_TE = Ns*Vp_rms/Np;
Is_rms_TE = (Vp_rms/r)*Np./Ns;

%Plot Vs_rms vs Ns
set(gca,'fontsize',fsize);
plot( Ns, Vs_rms, Ns, Vs_rms_TE );
xlabel('Number of secondary turns N_s');
ylabel('RMS secondary coil voltage /volts');
legend({'50Hz model', 'TE'},'fontsize',fsize); grid on;
title([' V_s vs N_s for N_p = ',num2str(Np),' turns.'])
print(gcf,'transformer_model V.png','-dpng','-r300');

%Plot Is_rms vs Ns
cla; set(gca,'fontsize',fsize);
plot( Ns, Is_rms, Ns, Is_rms_TE );
xlabel('Number of secondary turns N_s');
ylabel('RMS secondary coil current /A');
legend({'50Hz model', 'TE'},'fontsize',fsize); grid on;
title([' I_s vs N_s for N_p = ',num2str(Np),' turns.'])
print(gcf,'transformer_model I.png','-dpng','-r300');

%Plot power dissipated vs Ns
cla; set(gca,'fontsize',fsize);
plot( Ns, Pp, Ns, Ps );
xlabel('Number of secondary turns N_s');
ylabel('Power dissipated /W');
legend({'Primary', 'Secondary'},'location','best','fontsize',fsize); grid on;
title([' Power dissipated vs N_s for N_p = ',num2str(Np),' turns.'])
print(gcf,'transformer_model P.png','-dpng','-r300');
close(gcf);

%Plot power dissipated vs Ns
cla; set(gca,'fontsize',fsize);
plot( Ns, Pp_no_s*ones(size(Ns)),Ns, Pp, Ns, Ps );
xlabel('Number of secondary turns N_s');
ylabel('Power dissipated /W');
legend({'Primary no S','Primary', 'Secondary'},'location','best','fontsize',fsize); grid on;
title([' Power dissipated vs N_s for N_p = ',num2str(Np),' turns.'])
print(gcf,'transformer_model P inc no S.png','-dpng','-r300');
close(gcf);

%End of code






